@@ -34,6 +34,8 @@ class ogs(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.rm):
         super(ogs, self).__init__(**kwargs)
 
         self.__cmake_args = kwargs.get("cmake_args", [])
+        self.__cmake_preset = kwargs.get("cmake_preset", "release")
+        self.__cmake_preset_file = kwargs.get("cmake_preset_file", None)
         self.__ospackages = []
         self.__parallel = kwargs.get("parallel", 4)
         self.__prefix = kwargs.get("prefix", "/usr/local/ogs")
@@ -47,13 +49,13 @@ class ogs(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.rm):
         self.__branch = kwargs.get("branch", "master")
         self.__commit = kwargs.get("commit")
         self.__git_version = kwargs.get("git_version")
-        self.__conan = kwargs.get("conan", False)
-        self.__shell_args = ""
+        self.__shell_args = kwargs.get("mount_args", "")
+        self.__run_ctest = kwargs.get("run_ctest", False)
 
         if self.__repo == "local":
             self.__skip_clone = True
             self.__remove_source = False
-            self.__shell_args = "--mount=type=bind,target={}/src,rw".format(
+            self.__shell_args += " --mount=type=bind,target={}/src,rw".format(
                 self.__prefix
             )
 
@@ -104,13 +106,21 @@ class ogs(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.rm):
                     "(cd src && git reset --hard {})".format(self.__commit)
                 )
             self.__commands.append("(cd src && git fetch --tags)")
+        if self.__cmake_preset_file:
+            f = open(self.__cmake_preset_file, "r")
+            contents = f.read()
+            contents = contents.replace("\n", "\\n")
+            self.__commands.append(
+                f"echo '{contents}' >> /usr/local/ogs/src/CMakeUserPresets.json"
+            )
 
         # Default CMake arguments
         self.__cmake_args.extend(
             [
                 "-G Ninja",
                 "-DCMAKE_INSTALL_PREFIX={}".format(self.__prefix),
-                "-DCMAKE_BUILD_TYPE=Release",
+                "-DOGS_CPU_ARCHITECTURE=OFF",  # optimization handled via --cpu-target argument
+                "-DOGS_INSTALL_EXTERNAL_DEPENDENCIES=ON",
             ]
         )
 
@@ -119,39 +129,48 @@ class ogs(bb_base, hpccm.templates.CMakeBuild, hpccm.templates.rm):
         )
         if self.__toolchain.CC == "mpicc":
             self.__cmake_args.append("-DOGS_USE_PETSC=ON")
-            if self.__conan:
-                self.__cmake_args.append("-DOGS_CONAN_USE_SYSTEM_OPENMPI=ON")
-        if not self.__conan:
-            self.__cmake_args.append("-DOGS_USE_CONAN=OFF")
+
+        build_directory = "{}/build".format(self.__prefix)
+        self.__cmake_args.extend(
+            [f"--preset={self.__cmake_preset}", "-B", build_directory]
+        )
 
         # Configure and build
         self.__commands.append(
             self.configure_step(
                 directory="{}/src".format(self.__prefix),
-                build_directory="{}/build".format(self.__prefix),
+                build_directory=build_directory,
                 opts=self.__cmake_args,
                 toolchain=self.__toolchain,
             )
         )
+
+        # Install only when build dir is removed
         self.__commands.append(
-            self.build_step(target="install", parallel=self.__parallel)
+            self.build_step(
+                target=("install" if self.__remove_build else "all"),
+                parallel=self.__parallel,
+            )
         )
 
+        # ctest
+        if self.__run_ctest:
+            self.__commands.append(self.build_step(target="ctest"))
+
         # Cleanup
+        bin_dir = f"{self.__prefix}/build/bin"
         if self.__remove_build:
             self.__commands.append(
                 self.cleanup_step(items=[os.path.join(self.__prefix, "build")])
             )
-        else:
-            # Just run the clean-target
-            self.__commands.append(self.build_step(target="clean"))
+            bin_dir = f"{self.__prefix}/bin"
         if self.__remove_source:
             self.__commands.append(
                 self.cleanup_step(items=[os.path.join(self.__prefix, "src")])
             )
 
         # Environment
-        self.__environment_variables["PATH"] = "{0}/bin:$PATH".format(self.__prefix)
+        self.__environment_variables["PATH"] = f"{bin_dir}:$PATH"
 
         # Labels
         if self.__repo == "local":
