@@ -17,7 +17,6 @@ from hpccm.building_blocks import (
     packages,
     pip,
 )
-from ogscm.building_blocks.pm_conan import pm_conan
 
 import hpccm
 from ogscm.building_blocks.paraview import paraview
@@ -36,7 +35,7 @@ parse_g = parser.add_argument_group(filename)
 parse_g.add_argument(
     "--pm",
     type=str,
-    choices=["system", "conan", "off"],
+    choices=["system", "off"],
     default="system",
     help="Package manager to install third-party " "dependencies",
 )
@@ -58,11 +57,29 @@ parse_g.add_argument(
     " start with a space. e.g. --cmake_args ' -DFIRST="
     "TRUE -DFOO=BAR'",
 )
+parse_g.add_argument(
+    "--cmake_preset",
+    type=str,
+    default="release",
+    help="A CMake configuration preset to use.",
+)
+parse_g.add_argument(
+    "--cmake_preset_file",
+    type=str,
+    default=None,
+    help="A CMake (user) presets file as a local file path.",
+)
 parse_g.add_argument(
     "--ccache",
     dest="ccache",
     action="store_true",
-    help="Enables ccache build caching.",
+    help="Enables ccache build caching. (Docker-only)",
+)
+parse_g.add_argument(
+    "--cpmcache",
+    dest="cpmcache",
+    action="store_true",
+    help="Enables CPM source caching. (Docker-only)",
 )
 parse_g.add_argument(
     "--parallel",
@@ -125,6 +142,30 @@ if toolchain.CC == "mpicc":
         help="PETSc configuration arguments; has to be quoted.",
     )
 parse_g.add_argument("--version_file", type=str, help="OGS versions.json file")
+parse_g.add_argument(
+    "--boost-sourceforge",
+    dest="boost_sourceforge",
+    action="store_true",
+    help="Boolean flag to specify whether Boost should be downloaded from SourceForge rather than the current Boost repository.",
+)
+parse_g.add_argument(
+    "--keep-ogs-source",
+    dest="keep_source",
+    action="store_true",
+    help="Boolean flag to specify whether the OGS source directory should be preserved.",
+)
+parse_g.add_argument(
+    "--keep-ogs-build",
+    dest="keep_build",
+    action="store_true",
+    help="Boolean flag to specify whether the OGS build directory should be preserved.",
+)
+parse_g.add_argument(
+    "--run-ctest",
+    dest="run_ctest",
+    action="store_true",
+    help="Boolean flag to specify whether to run the OGS ctest-target.",
+)
 
 # Parse local args
 local_args = parser.parse_known_args()[0]
@@ -133,15 +174,12 @@ branch_is_release = False
 git_version = ""
 name_start = ""
 repo = None
-versions = None
-versions_master = json.loads(
-    requests.get(
-        f"https://gitlab.opengeosys.org/ogs/ogs/-/raw/master/web/data/versions.json?inline=false"
-    ).text
-)
 
 if local_args.ogs not in ["off", "clean"]:  # != "off" and local_args.ogs != "clean":
     if os.path.isdir(local_args.ogs):
+        if local_args.run_ctest and args.format == "docker":
+            print("`--run_ctest` can not be used with `--ogs local/path`")
+            exit(1)
         repo = "local"
         commit_hash = subprocess.run(
             ["cd {} && git rev-parse HEAD".format(local_args.ogs)],
@@ -220,6 +258,12 @@ if versions == None:
         ).text
     )
 
+if local_args.cmake_preset_file:
+    # Make path absolute
+    local_args.cmake_preset_file = os.path.abspath(
+        os.path.expanduser(os.path.expandvars(local_args.cmake_preset_file))
+    )
+
 folder = f"/{name_start}/{local_args.pm}".replace("//", "/")
 
 if len(local_args.cmake_args) > 0:
@@ -253,6 +297,7 @@ if local_args.gui:
             "libgl1-mesa-dev",
             "libglu1-mesa-dev",
             "libxt-dev",
+            "libglib2.0-0",
         ],
         yum=[
             "mesa-libOSMesa-devel",
@@ -271,61 +316,49 @@ if local_args.gui:
         ],
         yum=["mesa-libOSMesa", "mesa-libGL", "mesa-libGLU", "libXt"],
     )
+
+versions_master = json.loads(
+    requests.get(
+        f"https://gitlab.opengeosys.org/ogs/ogs/-/raw/master/web/data/versions.json?inline=false"
+    ).text
+)
+
 if local_args.ogs != "clean":
     cmake_version = versions_master["tested_version"]["cmake"]
     if "cmake" in versions["tested_version"]:
         cmake_version = versions["tested_version"]["cmake"]
     Stage0 += cmake(eula=True, version=cmake_version)
-    if local_args.pm == "conan":
-        conan_user_home = "/opt/conan"
-        if local_args.dev:
-            conan_user_home = ""
-        Stage0 += pm_conan(
-            user_home=conan_user_home, version=versions["minimum_version"]["conan"]
-        )
-        Stage0 += environment(variables={"CONAN_SYSREQUIRES_SUDO": 0})
-    elif local_args.pm == "system":
-        boost_bootsrap_opts = []
+    if local_args.pm == "system":
         if local_args.mfront:
             # for mfront python bindings
             boost_bootsrap_opts = ["--with-python=python3"]
-        if toolchain.CC == "clang":
-            boost_bootsrap_opts.append("--with-toolset=clang")
-        Stage0 += boost(
-            b2_opts=["headers"],
-            baseurl=f"https://boostorg.jfrog.io/artifactory/main/release/{versions['minimum_version']['boost']}/source",
-            bootstrap_opts=boost_bootsrap_opts,
-            ldconfig=True,
-            version=versions["minimum_version"]["boost"],
-        )
-        Stage0 += environment(variables={"BOOST_ROOT": "/usr/local/boost"})
+            if toolchain.CC == "clang":
+                boost_bootsrap_opts.append("--with-toolset=clang")
+            Stage0 += boost(
+                b2_opts=["headers"],
+                bootstrap_opts=boost_bootsrap_opts,
+                ldconfig=True,
+                sourceforge=local_args.boost_sourceforge,
+                version="1.75.0",  # versions["minimum_version"]["boost"], # is too old for gcc 11
+            )
+            Stage0 += environment(variables={"BOOST_ROOT": "/usr/local/boost"})
         Stage0 += packages(
             apt=["libxml2-dev", "xsltproc"], yum=["libxml2-devel", "libxslt"]
         )
         vtk_cmake_args = []
         if "libraries" in versions:
             for option in versions["libraries"]["vtk"]["options"]:
-                if (
-                    option["condition"] == "1"
-                    or (
-                        option["condition"] == "OGS_USE_MPI" and toolchain.CC == "mpicc"
-                    )
-                    or (option["condition"] == "OGS_BUILD_GUI" and local_args.gui)
-                    or (
-                        option["condition"] == "OGS_BUILD_TESTING"
-                        and local_args.ogs == "off"
-                    )
-                ):
+                if eval(option["condition"]["ogscm"]):
                     for cmake_option in option["cmake"]:
                         vtk_cmake_args.append(f"-D{cmake_option}")
             # Reverse so the VTK_GROUP_ vars are at the end of the list, otherwise they have no effect.
             vtk_cmake_args = vtk_cmake_args[::-1]
         else:
             vtk_cmake_args = [
-                "-DModule_vtkIOXML=ON",
-                "-DModule_vtkIOLegacy=ON",
-                "-DVTK_Group_Rendering=OFF",
-                "-DVTK_Group_StandAlone=OFF",
+                "-DVTK_MODULE_ENABLE_VTK_IOXML=YES",
+                "-DVTK_MODULE_ENABLE_VTK_IOLegacy=YES",
+                "-DVTK_GROUP_ENABLE_Rendering=DONT_WANT",
+                "-DVTK_GROUP_ENABLE_StandAlone=DONT_WANT",
             ]
             if local_args.gui:
                 vtk_cmake_args = [
@@ -336,8 +369,8 @@ if local_args.ogs != "clean":
             if toolchain.CC == "mpicc":
                 vtk_cmake_args.extend(
                     [
-                        "-DModule_vtkIOParallelXML=ON",
-                        "-DModule_vtkParallelMPI=ON",
+                        "-DVTK_MODULE_ENABLE_VTK_IOParallelXML=YES",
+                        "-DVTK_MODULE_ENABLE_VTK_ParallelMPI=YES",
                     ]
                 )
 
@@ -435,6 +468,8 @@ if local_args.ogs != "clean":
             )
         if toolchain.CC == "mpicc":
             Stage0 += packages(yum=["diffutils"])
+            if "--download-ptscotch" in local_args.petsc_configure_args:
+                Stage0 += packages(ospackages=["bison", "flex"])
             petsc_version = versions["minimum_version"]["petsc"]
             petsc_args = local_args.petsc_configure_args.strip().split(" ")
             petsc_configure_opts = [
@@ -499,13 +534,14 @@ if local_args.cvode:
     )
 
 if local_args.cppcheck:
+    cppcheck_version = "2.7.5"
     Stage0 += generic_cmake(
         devel_environment={"PATH": "/usr/local/cppcheck/bin:$PATH"},
-        directory="cppcheck-809a769c690d8ab6fef293e41a29c8490512866e",
+        directory=f"cppcheck-{cppcheck_version}",
         prefix="/usr/local/cppcheck",
         runtime_environment={"PATH": "/usr/local/cppcheck/bin:$PATH"},
         toolchain=toolchain,
-        url="https://github.com/danmar/cppcheck/archive/809a769c690d8ab6fef293e41a29c8490512866e.tar.gz",
+        url=f"https://github.com/danmar/cppcheck/archive/refs/tags/{cppcheck_version}.tar.gz",
     )
 
 if local_args.docs:
@@ -523,7 +559,7 @@ if local_args.mfront and local_args.pm == "system":
     if "tfel-rliv" in versions["minimum_version"]:
         tfel_version = versions["minimum_version"]["tfel-rliv"]
     Stage0 += generic_cmake(
-        cmake_opts=["-Denable-python-bindings=ON"],
+        cmake_opts=["-Denable-python-bindings=ON", "-Denable-portable-build=ON"],
         directory=f"tfel-rliv-{tfel_version}",
         ldconfig=True,
         url=f"https://github.com/thelfer/tfel/archive/refs/heads/rliv-{tfel_version}.zip",
@@ -554,7 +590,10 @@ if local_args.ccache:
 if local_args.ogs != "off" and local_args.ogs != "clean":
     mount_args = ""
     if local_args.ccache:
-        mount_args += f" --mount=type=cache,target=/opt/ccache,id=ccache"
+        mount_args += f" --mount=type=cache,target=/opt/ccache"
+    if local_args.cpmcache:
+        mount_args += f" --mount=type=cache,target=/opt/cpmcache,sharing=locked"
+        cmake_args.append("-DCPM_SOURCE_CACHE=/opt/cpmcache")
     if local_args.cvode:
         cmake_args.append("-DOGS_USE_CVODE=ON")
     if local_args.gui:
@@ -572,13 +611,16 @@ if local_args.ogs != "off" and local_args.ogs != "clean":
         repo=repo,
         branch=branch,
         commit=commit_hash,
-        conan=(True if local_args.pm == "conan" else False),
         git_version=git_version,
         toolchain=toolchain,
         cmake_args=cmake_args,
+        cmake_preset=local_args.cmake_preset,
+        cmake_preset_file=local_args.cmake_preset_file,
         parallel=local_args.parallel,
-        remove_build=True,
-        remove_source=True,
+        remove_build=not local_args.keep_build,
+        remove_source=not local_args.keep_source,
+        mount_args=mount_args,
+        run_ctest=local_args.run_ctest,
     )
 
 # Required for vtk from Python (for notebooks, VTUInterface)
